#!/bin/ksh
##########################################################################
# This script will read a master file that contains  the list of pairs of data-control files.
# For each pair of data-control file it reads line by line, it will invoke the helper script - validateFile.sh,
# by passing the data and control file names as command line arguments. 
#
#In the directory where the script is executed, there will be 3 directories - 
#1) incoming
#2) processed
#3) error
#./incoming is the directory where the data and control fles from FTP server would be dropped.
#./processed is the directory where the valid data and control files would be moved to after 
#copying the data file to the "config/variants/var1/partitions/part1/data/Informatica" path.
#./error is the directory where the invalid data file would be moved to.
##########################################################################

##########################################################################
#Function to send mail to the Production Support group 
##########################################################################

sendMailToSupport(){
	#Default mail subject and mail body
	mailSub="DEV INSTANCE - AP Inbound Error: Invalid data file"
	mailBody="The number of records in the data file does not match the count of records specified by the control file. Moving the pair of data and control files to the './error' directory"

	#In Production, the default mail address to which notification would be sent, will be AribaSupport@cvs.com
	#For Development, System Testing and UAT, change the value with the email IDs of the appropriate 
	#users/group.
	mailAdd="sirungbam@cvs.com"
	writeToLog "Function sendMailToSupport() entered"
	##########################################################################
	#The files, containing the subject and body of the mail, passed as arguments to this function
	##########################################################################

	errMailSubFile="$1"
	errMailBodyFile="$2"

	#The file that contains the list of comma separated email IDs to which the notification mail
	#would be sent.
	mailingListFile="./supportMailingList.txt"
	
	if [ -f $errMailSubFile -a -r $errMailSubFile ];
	then
		mailSub=`cat $errMailSubFile`
		writeToLog "File $errMailSubFile found"
	fi
	
	if [ -f $errMailBodyFile -a -r $errMailBodyFile ];
	then
		mailBody=`cat $errMailBodyFile`
		writeToLog "File $errMailBodyFile found"
	fi

	if [ -f $mailingListFile -a -r $mailingListFile ];
	then
		mailAdd=`cat $mailingListFile`
		writeToLog "File $mailingListFile found"
	fi

	writeToLog "mailSub = $mailSub"
	writeToLog "mailBody = $mailBody"
	writeToLog "mailAdd = $mailAdd"

	#mailx -s "$mailSub" "$mailAdd" < $mailBody
	echo "$mailBody" | mailx -s "$mailSub" "$mailAdd"
	writeToLog "Notification mail sent to Support group $mailAdd"
}

###################################################################
#Function to record the steps to a log file.
#When the Development is complete, specify the correct path and log file
#Writes the message passed to this funtion to the log file
#Also, a logic to archive this log file once it reaches a permitted size
#needs to be implemented
###################################################################
writeToLog(){
	logFile="./logs/APInboundDataValidationLog.txt"
	echo "Time: `date`" >> $logFile
	echo $1 >> $logFile
}


writeToLog "=====New Logs for data file validation====="
writeToLog "==========================================="

validateScript="./validateFile.sh"
masterFile="./MasterFile.csv"

if [ ! -f $masterFile -o ! -r $masterFile ];
then
	#exit for now, it will check again when the next cron job runs
	writeToLog "In Script $0: file $masterFile not found/readable"
	exit 0
fi

if [ ! -f $validateScript -o ! -r $validateScript ];
then
	#exit for now, it will check again when the next cron job runs
	writeToLog "In Script $0: script $validateScript not found/readable"
	exit 0
fi

writeToLog "In Script $0: Going to validate all data files listed in the master file - $masterFile"
count=0
while [ 1 ]
    do
		#execute the following block from the 2nd line onwards, which means skip the header row of the csv file
		read entryLine || break
		writeToLog "In Script $0: entryLine=$entryLine"
		if [ $count -gt 0 ];
		then		
			#index of the delimiter that separates the data file and control file names	   
			index=`echo $entryLine | awk '{ print index($1,",") }'`
			writeToLog "In Script $0: index of delimiter = $index"
			#need to take the substring before the comma
			index=`expr $index - 1`	   
			#echo $entryLine | awk '{ print substr($1, 0, '$index') }'
			dataFile=`echo $entryLine | awk '{ print substr($1, 0, '$index') }'`	   
			writeToLog "In Script $0: current data file = $dataFile"	
			index=`expr $index + 2`			
			controlFile=`echo $entryLine | awk '{ print substr($1, '$index') }'`
			writeToLog "In Script $0: current control file = $controlFile"  	   
			#invoke script - $validateScript
			sh $validateScript $dataFile $controlFile
		fi
	   count=`expr $count + 1`
	   #echo "count = $count"
    done < $masterFile
writeToLog "In Script $0: Finished validation of all data files listed in the master file - $masterFile"

exit 0

