#!/bin/ksh
##########################################################################
#This script will validate if the data file has the complete number of records 
#as specified by the record count (NUMRECS) of the corresponding control file.
#
#In the directory where the script is executed, there will be 3 directories - 
#1) incoming
#2) processed
#3) error
#./incoming is the directory where the data and control fles from FTP server would be dropped.
#./processed is the directory where the valid data and control files would be moved to after 
#copying the data file to the "config/variants/var1/partitions/part1/data/Informatica" path.
#./error is the directory where the invalid data file would be moved to.
##########################################################################

##########################################################################
#Function to send mail to the Production Support group 
##########################################################################

sendMailToSupport(){
	#Default mail subject and mail body
	mailSub="DEV INSTANCE - AP Inbound Error: Invalid data file"
	mailBody="The number of records in the data file does not match the count of records specified by the control file. Moving the pair of data and control files to the './error' directory"

	#In Production, the default mail address to which notification would be sent, will be AribaSupport@cvs.com
	#For Development, System Testing and UAT, change the value with the email IDs of the appropriate 
	#users/group.
	mailAdd="sirungbam@cvs.com"

	##########################################################################
	#The files, containing the subject and body of the mail, passed as arguments to this function
	##########################################################################

	errMailSubFile="$1"
	errMailBodyFile="$2"

	#The file that contains the list of comma separated email IDs to which the notification mail
	#would be sent.
	mailingListFile="./supportMailingList.txt"
	
	if [ -f $errMailSubFile -a -r $errMailSubFile ];
	then
		mailSub=`cat $errMailSubFile`
	fi
	
	if [ -f $errMailBodyFile -a -r $errMailBodyFile ];
	then
		mailBody=`cat $errMailBodyFile`
	fi

	if [ -f $mailingListFile -a -r $mailingListFile ];
	then
		mailAdd=`cat $mailingListFile`
	fi
	
	#mailx -s "$mailSub" "$mailAdd" < $mailBody
	echo "$mailBody" | mailx -s "$mailSub" "$mailAdd"
}


##########################################################################
#Specify the names of the data and control files while invoking this script
#The script will prefix the path ./incoming/ to the names of the files
##########################################################################

if [ $# -ne 2 ]
then
	echo "Usage: $0 validateFile '<dataFile>' '<controlFile>'"
        exit 1
fi

echo "First argument is: $1"
echo "Second argument is: $2"

dataFile=$1
ctrlFile=$2

echo $dataFile
echo $ctrlFile

if [ ! -f "./incoming/$dataFile" -o ! -r "./incoming/$dataFile" ];
then
	#exit for now, it will check again when the next cron job runs
	echo $dataFile not found
	exit 0
fi

if [ ! -f "./incoming/$ctrlFile" -o ! -r "./incoming/$ctrlFile" ];
then
	#exit for now, it will check again when the next cron job runs
	echo $ctrlFile not found
	exit 0
fi

lineCount=`wc -l ./incoming/$dataFile | cut -c1-8`
lineCount=`expr $lineCount - 1`
echo Number of data rows = $lineCount

keyVal=""
while [ 1 ]
    do
       read keyVal || break
       echo $keyVal
       export $keyVal
    done < ./incoming/$ctrlFile
echo "Number of records = ${NUMRECS}"

if [ $lineCount -ne $NUMRECS ]
then
	#################################################################################
	#move the data and control files to the ./error directory and send email to Support
	#################################################################################

        #mailSub=`cat ./validationErrMailSub.txt`
        #mailAdd=`cat ./supportMailAddresses.txt`
        #mailBody=`cat ./validationErrMailBody.txt`
	mkdir -p ./error
	mv ./incoming/$dataFile ./error/$dataFile
	mv ./incoming/$ctrlFile ./error/$ctrlFile
	sendMailToSupport "./validationErrMailSub.txt" "./validationErrMailBody.txt"
	exit 1
fi


################################################################################
#Validation passed. Copy the data file to the path - "config/variants/var1/partitions/part1/data/Informatica"
#and then move the data and control files to the ./processed directory
################################################################################

###############################################################################
#Yet to implement the code for copying the data file to the data/Informatica path
#Need to know where this script will be residing
###############################################################################

mkdir -p ./processed
mv ./incoming/$dataFile ./processed/$dataFile
mv ./incoming/$ctrlFile ./processed/$ctrlFile

exit 0

